<?php

	// データベースクラス
	class BlogDB {

		private $_dbfile;

		function __construct($db_info) {

			// DBファイルのパスを保存
			$this->_dbfile = $db_info;

		}

		// データベース存在確認
		function existDB() {

			// データベースファイルが存在しなければFALSEを返す
			if (!is_file($this->_dbfile)) {
				return FALSE;
			}

			return TRUE;

		}

		// データベース利用可否
		function canOpen() {

			// データベースファイルが存在しなければFALSEを返す
			if (!$this->existDB()) {
				return FALSE;
			}

			// データベースを開く
			$db = sqlite_open($this->_dbfile);

			// open失敗ならFALSEを返す
			if ($db == FALSE) {
				return FALSE;
			}

			// データベースファイルを閉じる
			sqlite_close($db);

			return TRUE;

		}

		// データベース初期化
		function createDB() {

			// 既存データベースを一度削除
			if (is_file($this->_dbfile)) {
				unlink($this->_dbfile);
			}

			// データベースを開く
			$db = sqlite_open($this->_dbfile);

			// open失敗ならFALSEを返す
			if ($db == FALSE) {
				return FALSE;
			}

			// 記事テーブル作成用SQL
			$sql = "create table article(id integer primary key, writedate integer, changedate integer, title text, body text, indexsummary text, atomsummary text)";

			sqlite_exec($db, $sql);

			sqlite_close($db);

			return TRUE;

		}

		// 指定IDの記事取得
		function getArticle($id) {

			// データベースが存在しなければFALSEを返す
			if (!$this->existDB()) {
				return FALSE;
			}

			// データベースを開く
			$db = sqlite_open($this->_dbfile);

			// データベースを開けなければFALSEを返す
			if ($db == FALSE) {
				return FALSE;
			}

			// 指定IDの記事を検索するSQL文作成
			$sql = 'select * from article where id=' . $id;

			// SQLクエリを実行
			$result = sqlite_query($db, $sql);

			if (!$result) {

				sqlite_close($db);

				return FALSE;

			}

			$row = sqlite_fetch_array($result);

			sqlite_close($db);

			// 記事を取得できたら結果を連想配列で返す
			if ($row) {

				$article = array();

				$article['id'] = $row['id'];
				$article['writedate'] = $row['writedate'];
				$article['changedate'] = $row['changedate'];
				$article['title'] = str_replace('\"', '"', $row['title']);
				$article['body'] = str_replace('\"', '"', $row['body']);
				$article['indexsummary'] = str_replace('\"', '"', $row['indexsummary']);
				$article['atomsummary'] = str_replace('\"', '"', $row['atomsummary']);

				return $article;

			} else {
				return FALSE;
			}

		}

		// 指定IDの記事削除
		function deleteArticle($id) {

			// データベースが存在しなければFALSEを返す
			if (!$this->existDB()) {
				return FALSE;
			}

			// データベースを開く
			$db = sqlite_open($this->_dbfile);

			$sql = 'delete from article where id=' . $id;

			sqlite_exec($db, $sql);

			sqlite_close($db);

			return TRUE;

		}

		// （offset + 1）番目以降の記事を最大$num件取得
		function getArticleList($offset = 0, $num = -1) {

			$result = array();

			$result["itemNum"] = 0;
			$result["itemList"] = FALSE;

			// 取得件数が0、またはデータベースが存在しなければFALSEを返す
			if ($num == 0 || (!$this->existDB())) {
				return FALSE;
			}

			// データベースを開く
			$db = sqlite_open($this->_dbfile);

			// データベースを開けなければFALSEを返す
			if ($db == FALSE) {
				return FALSE;
			}

			$sql = 'select COUNT(id) from article';

			// 記事件数を取得
			$count = sqlite_query($db, $sql);

			if (!$count) {

				sqlite_close($db);

				return FALSE;

			}

			// 記事件数を記録
			$result["itemNum"] = sqlite_fetch_single($count);

			$sql = 'select * from article order by id desc';

			if ($num > 0) {
				 $sql = $sql . ' limit ' . $num;
			}

			if ($offset > 0) {
				 $sql = $sql . ' offset ' . $offset;
			}

			$itemList = sqlite_query($db, $sql);

			if (!$itemList) {

				sqlite_close($db);

				return FALSE;

			}

			// 記事配列を作成
			$articleList = array();

			// 取得した各記事を記事配列に格納
			while ($row = sqlite_fetch_array($itemList)){ 

				// 個別記事情報を格納する連想配列を作成
				$article = array();

				$article['id'] = $row['id'];
				$article['writedate'] = $row['writedate'];
				$article['changedate'] = $row['changedate'];
				$article['title'] = str_replace('\"', '"', $row['title']);
				$article['body'] = str_replace('\"', '"', $row['body']);
				$article['indexsummary'] = str_replace('\"', '"', $row['indexsummary']);
				$article['atomsummary'] = str_replace('\"', '"', $row['atomsummary']);

				// 記事配列に追加
				$articleList[] = $article;

			}

			sqlite_close($db);

			$result["itemList"] = $articleList;

			return $result;

		}

		// （offset + 1）番目以降の記事を最大$num件取得（更新順）
		function getUpdatedArticleList($offset = 0, $num = -1) {

			$result = array();

			$result["itemNum"] = 0;
			$result["itemList"] = FALSE;

			// 取得件数が0、またはデータベースが存在しなければFALSEを返す
			if ($num == 0 || (!$this->existDB())) {
				return FALSE;
			}

			// データベースを開く
			$db = sqlite_open($this->_dbfile);

			// データベースを開けなければFALSEを返す
			if ($db == FALSE) {
				return FALSE;
			}

			$sql = 'select COUNT(id) from article';

			// 記事件数を取得
			$count = sqlite_query($db, $sql);

			if (!$count) {

				sqlite_close($db);

				return FALSE;

			}

			// 記事件数を記録
			$result["itemNum"] = sqlite_fetch_single($count);

			$sql = 'select * from article order by changedate desc';

			if ($num > 0) {
				 $sql = $sql . ' limit ' . $num;
			}

			if ($offset > 0) {
				 $sql = $sql . ' offset ' . $offset;
			}

			$itemList = sqlite_query($db, $sql);

			if (!$itemList) {

				sqlite_close($db);

				return FALSE;

			}

			// 記事配列を作成
			$articleList = array();

			// 取得した各記事を記事配列に格納
			while ($row = sqlite_fetch_array($itemList)){ 

				// 個別記事情報を格納する連想配列を作成
				$article = array();

				$article['id'] = $row['id'];
				$article['writedate'] = $row['writedate'];
				$article['changedate'] = $row['changedate'];
				$article['title'] = str_replace('\"', '"', $row['title']);
				$article['body'] = str_replace('\"', '"', $row['body']);
				$article['indexsummary'] = str_replace('\"', '"', $row['indexsummary']);
				$article['atomsummary'] = str_replace('\"', '"', $row['atomsummary']);

				// 記事配列に追加
				$articleList[] = $article;

			}

			sqlite_close($db);

			$result["itemList"] = $articleList;

			return $result;

		}

		// 記事書き込み
		function writeArticle($item) {

			// データベースが存在しなければFLASEを返す
			if (!$this->existDB()) {
				return FALSE;
			}

			// 記事を新規追加・または上書き更新
			if (!$this->getArticle($item["id"])) {
				return $this->addArticle($item);
			} else {
				return $this->updateArticle($item);
			}

		}

		// 記事更新
		function updateArticle($item) {

			// データベースが存在しなければFLASEを返す
			if (!$this->existDB()) {
				return FALSE;
			}

			$item["title"] = sqlite_escape_string($item["title"]);
			$item["body"] = sqlite_escape_string($item["body"]);
			$item["indexsummary"] = sqlite_escape_string($item["indexsummary"]);
			$item["atomsummary"] = sqlite_escape_string($item["atomsummary"]);

			// 更新SQL作成
			$sql = "update article set writedate=" . $item["writedate"] . ",changedate=" . $item["changedate"] . ",title='" . $item["title"] . "',body='" . $item["body"] . "',indexsummary='" . $item["indexsummary"] . "',atomsummary='" . $item["atomsummary"] . "' where id=" . $item["id"];

			// データベースを開く
			$db = sqlite_open($this->_dbfile);

			// データベースを開けなければFALSEを返す
			if ($db == FALSE) {
				return FALSE;
			}

			if (sqlite_exec($db, $sql)) {
				$result = TRUE;
			} else {
				$result = FALSE;
			}

			sqlite_close($db);

			return $result;

		}

		// 記事新規作成
		function addArticle($item) {

			// データベースが存在しなければFALASEを返す
			if (!$this->existDB()) {
				return FALSE;
			}

			$item["title"] = sqlite_escape_string($item["title"]);
			$item["body"] = sqlite_escape_string($item["body"]);
			$item["indexsummary"] = sqlite_escape_string($item["indexsummary"]);
			$item["atomsummary"] = sqlite_escape_string($item["atomsummary"]);

			// 新規登録SQL作成
			$sql = "insert into article values(" . $item["id"] . "," . $item["writedate"] . "," . $item["changedate"] . ",'" . $item["title"] . "','" . $item["body"] . "','" . $item["indexsummary"] . "','" . $item["atomsummary"] . "')";

			// データベースを開く
			$db = sqlite_open($this->_dbfile);

			// データベースを開けなければFLSEを返す
			if ($db == FALSE) {
				return FALSE;
			}

			if (sqlite_exec($db, $sql)) {
				$result = TRUE;
			} else {
				$result = FALSE;
			}

			sqlite_close($db);

			return $result;

		}

	}

?>
